@@ -31,5 +31,7 @@ class LLMMoi(ModelOfInterestingness):
 
         task.interesting = result.interesting
 
-        metadata = log_llm_call(run.dir / "llm_logs", task.id, "moi", result=result, completion=completion)
+        metadata = log_llm_call(
+            run.resolve_path(run.paths.llm_log_dir, task.id), task.id, "moi", result=result, completion=completion
+        )
         task.metadata.setdefault("llm_calls", []).append(metadata)
