@@ -29,5 +29,11 @@ class LLMTaskGenerator(TaskGenerator):
 
         task.description = result.task
 
-        metadata = log_llm_call(run.dir / "llm_logs", task.id, "task_generator", result=result, completion=completion)
+        metadata = log_llm_call(
+            run.resolve_path(run.paths.llm_log_dir, task.id),
+            task.id,
+            "task_generator",
+            result=result,
+            completion=completion,
+        )
         task.metadata.setdefault("llm_calls", []).append(metadata)
